using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

using WesternGeco.Common.Windows.Forms;
using WesternGeco.Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Windows.Forms.Tools;
using Syncfusion.Drawing;
using Syncfusion.Grouping;

namespace WesternGeco.Sedm.IManage.UI.Tables
{
	public class SetColumnValuesUI
	{
		private GridGroupingControl grid;
		private Dialog dialog;
		private Panel panel;
		private string targetColumnName;
		private Control clientArea;
		private System.Windows.Forms.Label colLabel;
		private ComboBoxAutoComplete colNameComboBoxAutoComplete;
		private System.Windows.Forms.Label expressionLabel;
		private ComboBoxAutoComplete expressionComboBoxAutoComplete;
		private ArrayList columnList;
		private ArrayList expressionSampleList;

		public SetColumnValuesUI(GridGroupingControl grid, string columnName)
		{
			this.grid = grid;
			this.targetColumnName = columnName;
			this.columnList = new ArrayList();
			this.expressionSampleList = new ArrayList();
		}

		public void ShowDialog(Control parent)
		{
			if (dialog == null)
			{
				dialog = new Dialog(parent);
				dialog.ClientArea = this.BuildClientArea();
				dialog.AddButton("OK");
				dialog.AddButton("Apply");
				dialog.AddButton("Close");
				dialog.AddButton("Help");
				dialog.Resizability = Resizability.Full;
				dialog.Modality = Modality.None;
				dialog.ButtonClicked += new EventHandler(HandleButtonClicked);
			}
			dialog.Text = "Set Column Values";
			dialog.Show();
		}

		private void LayoutComponents()
		{
			this.clientArea.Text = "Enter column expression";
			TkGridLayout gl = new TkGridLayout(this.clientArea);
			gl.Add(this.panel, "-row 1 -col 1 -fill x");
			gl.MarginSize = LookAndFeelStandards.MarginSize;
			gl.RowConfigure(2, "-minsize 15");
			gl.AutoSize();
		}

		private Control BuildClientArea()
		{
			this.clientArea = new UserControl();
			this.dialog.Name = "Enter column expression";
			InitClientArea();
			PopulateComboBox();
			LayoutComponents();
			this.colNameComboBoxAutoComplete.Text = this.targetColumnName;
			this.panel.Visible = true;
			return this.clientArea;
		}

		private void PopulateComboBox()
		{

			// populate table columns
			for (int i=0; i<grid.TableDescriptor.Columns.Count; i++)
				this.columnList.Add(grid.TableDescriptor.Columns[i].Name);
			this.columnList.Sort();
			this.colNameComboBoxAutoComplete.AutoCompleteControl.DataSource = this.columnList;

			// populate expression samples
			this.expressionSampleList.Add("[SourcePoint] + [SwathNumber] + 3");
			this.expressionSampleList.Add("555");
			this.expressionSampleList.Add("[SourcePoint] * 100");
			this.expressionComboBoxAutoComplete.AutoCompleteControl.DataSource = this.expressionSampleList;
		}


		private void InitClientArea()
		{
			this.panel = new Panel();
			this.colLabel = new System.Windows.Forms.Label();
			this.colNameComboBoxAutoComplete = new ComboBoxAutoComplete();
			this.expressionLabel = new System.Windows.Forms.Label();
			this.expressionComboBoxAutoComplete = new ComboBoxAutoComplete();
			((System.ComponentModel.ISupportInitialize)(this.colNameComboBoxAutoComplete.AutoCompleteControl)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.expressionComboBoxAutoComplete.AutoCompleteControl)).BeginInit();
			this.panel.SuspendLayout();
			// 
			// label1
			// 
			this.colLabel.Location = new System.Drawing.Point(16, 32);
			this.colLabel.Name = "label1";
			this.colLabel.Size = new System.Drawing.Size(56, 23);
			this.colLabel.TabIndex = 0;
			this.colLabel.Text = "Column :";
			// 
			// colNameComboBoxAutoComplete.AutoCompleteControl
			// 
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AccessibleDescription = null;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AccessibleName = null;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AccessibleRole = System.Windows.Forms.AccessibleRole.None;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AdjustHeightToItemCount = true;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AutoAddItem = false;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.AutoSerialize = true;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.CategoryName = "";
			this.colNameComboBoxAutoComplete.AutoCompleteControl.ChangeDataManagerPosition = true;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.OverrideCombo = true;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.ParentForm = this.dialog;
			this.colNameComboBoxAutoComplete.AutoCompleteControl.PreferredHeight = 200;
			this.colNameComboBoxAutoComplete.DropDownWidth = 168;
			this.colNameComboBoxAutoComplete.ItemHeight = 13;
			this.colNameComboBoxAutoComplete.Name = "colNameComboBoxAutoComplete";
			this.colNameComboBoxAutoComplete.ParentForm = this.dialog;
			this.colNameComboBoxAutoComplete.Size = new System.Drawing.Size(300, 21);
			// 
			// expressionLabel
			// 
			this.expressionLabel.Location = new System.Drawing.Point(16, 104);
			this.expressionLabel.Name = "expressionLabel";
			this.expressionLabel.TabIndex = 2;
			this.expressionLabel.Text = "Enter expression :";
			// 
			// expressionComboBoxAutoComplete.AutoCompleteControl
			// 
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AccessibleDescription = null;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AccessibleName = null;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AccessibleRole = System.Windows.Forms.AccessibleRole.None;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AdjustHeightToItemCount = true;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AutoAddItem = false;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.AutoSerialize = true;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.CategoryName = "";
			this.expressionComboBoxAutoComplete.AutoCompleteControl.ChangeDataManagerPosition = true;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.OverrideCombo = true;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.ParentForm = this.dialog;
			this.expressionComboBoxAutoComplete.AutoCompleteControl.PreferredHeight = 200;
			this.expressionComboBoxAutoComplete.DropDownWidth = 168;
			this.expressionComboBoxAutoComplete.ItemHeight = 13;
			this.expressionComboBoxAutoComplete.Name = "expressionComboBoxAutoComplete";
			this.expressionComboBoxAutoComplete.ParentForm = this.dialog;
			this.expressionComboBoxAutoComplete.Size = new System.Drawing.Size(300, 21);
			this.expressionComboBoxAutoComplete.AllowNewText = true;
			//
			// SetColumnValuesUI
			// 
			this.clientArea.ClientSize = new System.Drawing.Size(264, 197);
			this.panel.Name = "ChartParamDialog";
			((System.ComponentModel.ISupportInitialize)(this.colNameComboBoxAutoComplete.AutoCompleteControl)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.expressionComboBoxAutoComplete.AutoCompleteControl)).EndInit();
			this.panel.ResumeLayout(false);

			TkGridLayout gl = new TkGridLayout(this.panel);
			gl.Add(this.colLabel, "-row 1 -col 1");
			gl.Add(this.colNameComboBoxAutoComplete, "-row 1 -col 2 -fill x");
			gl.Add(this.expressionLabel, "-row 2 -col 1");
			gl.Add(this.expressionComboBoxAutoComplete, "-row 2 -col 2 -fill x");
			gl.AutoSize();
		}

		private void HandleButtonClicked(object sender, EventArgs e)
		{
			Dialog d = sender as Dialog;
			if (d != null)
			{
				if (d.ClickedButton.Text == "Close")
				{
					d.Close();
				}
				else if (d.ClickedButton.Text == "Apply")
				{
					this.ApplyExpression();
				}
				else if (d.ClickedButton.Text == "OK")
				{
					this.ApplyExpression();
					d.Close();
				}
			}
		}

		private void ApplyExpression()
		{
			this.grid.TableDescriptor.ExpressionFields["ExpressionColumn"].Expression = this.expressionComboBoxAutoComplete.Text; 
			for (int i=0; i<this.grid.Table.Records.Count; i++)
			{
				try
				{
					Record record = this.grid.Table.Records[i];
					if (record != null)
						record.SetValue(this.colNameComboBoxAutoComplete.Text, record.GetValue("ExpressionColumn"));
				}
				catch (System.ArgumentException argex)
				{
					MessageBox.Show("Invalid data type. ",
									"Argumen Exception", MessageBoxButtons.OK, MessageBoxIcon.Warning);
					return;
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message, "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning);
					return;
				}
			}
			this.grid.Refresh();
		}
	}
}
